ListDecoder

Struct ListDecoder 

pub struct ListDecoder<'obj, 'ser: 'obj> { /* private fields */ }
A list read from the input stream

Implementations

Source

impl<'obj, 'ser: 'obj> ListDecoder<'obj, 'ser>

pub fn next_object<'item>( &'item mut self, ) -> Result<Option<Object<'item, 'ser>>, Error>

Get the next item from the list. Returns Ok(None) at the end of the list

pub fn consume_all(&mut self) -> Result<(), Error>

Consume (and validate the structure of) the rest of the items from the list. This method should be used to check for encoding errors if ListDecoder::next_object is not called until it returns Ok(()).

pub fn into_raw(self) -> Result<&'ser [u8], Error>

Get the raw bytes that made up this list